<?php

namespace Supportingcast;

use Requests;

class Api {

	private $baseUrl = '';
	private $token = '';
	/** @var \Requests_Response $response */
	private $response;
	private $body;

	public function __construct() {
		$this->baseUrl = 'https://api' . SC_API_DOMAIN_BASE . '/v1/';
		$this->token = get_option('sc-token');
	}

	public function post(string $path, ?array $body = null): void
	{
		$this->response = Requests::post(
			$this->baseUrl . $path,
			$this->getHeaders(),
			json_encode($body),
			$this->getOptions()
		);

	}

	public function get(string $path, ?array $body = null): void
	{
		$this->response = Requests::get(
			$this->baseUrl . $path,
			$this->getHeaders(),
			$this->getOptions()
		);
	}

	public function put(string $path, ?array $body = null): void
	{

		$this->response = Requests::put(
			$this->baseUrl . $path,
			$this->getHeaders(),
			json_encode($body),
			$this->getOptions()
		);

	}

	public function delete(string $path): void
	{
		$this->response = Requests::delete(
			$this->baseUrl . $path,
			$this->getHeaders(),
			$this->getOptions()
		);

	}

	public function success(): bool
	{
		return !is_wp_error($this->response) && $this->response->success;
	}

	public function getErrorMsg(): string
	{
		if (is_wp_error($this->response)) {
			return $this->response->get_error_message();
		}
		return '<i>' . $this->response->status_code . ' '
		       . $this->response->body . '</i> error from server. Please try again.';
	}

	/**
	 * @return \Requests_Response;
	 */
	public function getResponse()
	{
		return $this->response;
	}

	public function getBody()
	{
		if (!$this->body) {
			$this->body = json_decode($this->response->body);
		}
		return $this->body;
	}

	// for new Request:: calls
	private function getOptions() {
		return [
			'verify' => false,
			'timeout' => 30,
		];
	}

	private function getHeaders() {
		return [
			'Authorization' => 'Bearer ' . $this->token,
			'Content-type' => 'application/json',
			'Accept' => 'application/json',
		];
	}
}